==> qmmp-plugin-pack-2.2.2.tar.bz2: qmmp-plugin-pack-2.2.2/src/Engines/ffvideo/translations/ffvideo_plugin_kk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="kk_KZ">
<context>
    <name>FFVideoFactory</name>
    <message>
        <location filename="../ffvideofactory.cpp" line="41"/>
        <source>FFmpeg Video Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="45"/>
        <source>Video Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="161"/>
        <source>About FFVideo Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="162"/>
        <source>FFmpeg-based video plugin for Qmmp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="163"/>
        <source>Compiled against:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="172"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FFVideoMetaDataModel</name>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <source>Audio bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Audio sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>KiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <location filename="../ffvideometadatamodel.cpp" line="83"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="73"/>
        <location filename="../ffvideometadatamodel.cpp" line="75"/>
        <source>Audio channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="82"/>
        <source>Video size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="83"/>
        <source>Video bitrate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VideoWindow</name>
    <message>
        <location filename="../videowindow.cpp" line="40"/>
        <source>FFmpeg Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <location filename="../videowindow.cpp" line="51"/>
        <source>&amp;Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <location filename="../videowindow.cpp" line="51"/>
        <source>Space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="47"/>
        <location filename="../videowindow.cpp" line="52"/>
        <source>&amp;Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="47"/>
        <location filename="../videowindow.cpp" line="52"/>
        <source>V</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="49"/>
        <location filename="../videowindow.cpp" line="54"/>
        <source>&amp;Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="49"/>
        <location filename="../videowindow.cpp" line="54"/>
        <source>F</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-2.3.0.tar.bz2: qmmp-plugin-pack-2.3.0/src/Engines/ffvideo/translations/ffvideo_plugin_kk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="kk_KZ">
<context>
    <name>FFVideoFactory</name>
    <message>
        <location filename="../ffvideofactory.cpp" line="41"/>
        <source>FFmpeg Video Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="45"/>
        <source>Video Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="191"/>
        <source>About FFVideo Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="192"/>
        <source>FFmpeg-based video plugin for Qmmp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="193"/>
        <source>Compiled against:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="202"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FFVideoMetaDataModel</name>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <source>Audio bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Audio sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>KiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <location filename="../ffvideometadatamodel.cpp" line="86"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="73"/>
        <location filename="../ffvideometadatamodel.cpp" line="75"/>
        <source>Audio channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="79"/>
        <source>Audio format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="85"/>
        <source>Video size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="86"/>
        <source>Video bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="89"/>
        <source>Video format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VideoWindow</name>
    <message>
        <location filename="../videowindow.cpp" line="40"/>
        <source>FFmpeg Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <location filename="../videowindow.cpp" line="51"/>
        <location filename="../videowindow.cpp" line="70"/>
        <source>&amp;Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <location filename="../videowindow.cpp" line="51"/>
        <source>Space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="47"/>
        <location filename="../videowindow.cpp" line="52"/>
        <source>&amp;Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="47"/>
        <location filename="../videowindow.cpp" line="52"/>
        <source>V</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="49"/>
        <location filename="../videowindow.cpp" line="54"/>
        <source>&amp;Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="49"/>
        <location filename="../videowindow.cpp" line="54"/>
        <source>F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="75"/>
        <source>&amp;Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="80"/>
        <source>&amp;Play</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
